function x=fixpunkt(g,x0,tol)
% fixpunkt - fixpunktsiteration för den skalära ekvationen x=g(x) 
% 
%   Syntax: 
%           x = fixpunkt(g,x0,tol)
%   Inargument: 
%           g - funktionshandtag till en funktionsfil  
%           x0 - ett tal, startapproximation
%           tol - en tolerans
%   Utargument: 
%           x - ett tal, den approximativa lösningen
%   Beskrivning:
%          Programmet fixpunkt använder fixpunktsiteration för att 
%          beräkna en approximativ lösning till den skalära ekvationen 
%          x=g(x).  Funktionsfilen som g pekar på måste innehålla
%          funktionen y=g(x). Funktionen g:I->I måste vara en kontraktion
%          på något slutet intervall I.  Då har g en unik fixpunkt x_exakt
%          i I. Om startapproximationen x0 tillhör I, så beräknar 
%          programmet en approximativ lösning x med felet
%          |x-x_exakt| < tol/(1-L), där L är Lipschitz-konstanten för g.  
%   Exempel: 
%          x = fixpunkt(@cos, 1, 1e-7) beräknar x= 0.739085169944554
%   Se också:
%          bisekt.m
%
%----------------------------------------------------------------------

Skriv ditt program här! 
